import React from "react";
import { useQuery } from "@tanstack/react-query";
import { Link } from "wouter";
import { Helmet } from "react-helmet";
import { Stats } from "@shared/schema";
import { StatsCard } from "@/components/ui/stats-card";
import { DataTable } from "@/components/ui/data-table";
import { Button } from "@/components/ui/button";
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card";
import { Badge } from "@/components/ui/badge";
import { getIncidentTypeConfig, getIncidentStatus, STATUS_TYPES } from "@/lib/incident-types";
import { formatDate, formatTime, formatIncidentNumber } from "@/lib/utils";
import { 
  Flame, 
  Plus, 
  Edit, 
  MoreVertical, 
  FileDown,
  Car, 
  Activity,
  Truck,
  Bell
} from "lucide-react";
import { BarChart, Bar, XAxis, YAxis, CartesianGrid, Tooltip, ResponsiveContainer, PieChart, Pie, Cell } from "recharts";

export default function Dashboard() {
  // Fetch dashboard stats
  const { data: stats, isLoading } = useQuery<Stats>({
    queryKey: ["/api/stats"],
  });

  const recentIncidentsColumns = [
    {
      accessorKey: "id",
      header: "Call No", 
      cell: ({ row }) => {
        // Add 1 to make Call No start from 1 instead of 0
        return (
          <span className="font-medium">
            {row.index + 1}
          </span>
        );
      },
    },
    {
      accessorKey: "date",
      header: "Date",
      cell: ({ row }) => formatDate(row.original.date),
    },
    {
      accessorKey: "time",
      header: "Time",
      cell: ({ row }) => formatTime(row.original.time),
    },
    {
      accessorKey: "incidentNumber",
      header: "Incident No",
      cell: ({ row }) => (
        <span className="font-medium">
          {formatIncidentNumber(row.original.incidentNumber)}
        </span>
      ),
    },
    {
      accessorKey: "location",
      header: "Address",
      cell: ({ row }) => (
        <span className="block">
          {row.original.location}
        </span>
      ),
    },
    {
      accessorKey: "town",
      header: "Area",
      cell: ({ row }) => (
        <span className="block">
          {row.original.town || ""}
        </span>
      ),
    },
    {
      accessorKey: "station",
      header: "Stn Ground",
      cell: ({ row }) => (
        <span className="block">
          {row.original.station || ""}
        </span>
      ),
    },
    {
      accessorKey: "officerInCharge",
      header: "OIC",
      cell: ({ row }) => (
        <span className="block">
          {row.original.officerInCharge || ""}
        </span>
      ),
    },
    {
      accessorKey: "watch",
      header: "Watch",
      cell: ({ row }) => {
        const watch = row.original.watch || "";
        let bgColor = "bg-transparent";
        
        if (watch.toLowerCase().includes("green")) {
          bgColor = "bg-green-500 text-black font-medium";
        } else if (watch.toLowerCase().includes("red") && !watch.toLowerCase().includes("rds")) {
          bgColor = "bg-red-500 text-black font-medium";
        } else if (watch.toLowerCase().includes("blue")) {
          bgColor = "bg-blue-500 text-black font-medium";
        } else if (watch.toLowerCase().includes("white")) {
          bgColor = "bg-white border border-gray-300 text-black font-medium";
        } else if (watch.toLowerCase().includes("rds")) {
          bgColor = "bg-amber-500 text-black font-medium";
        }
        
        return (
          <span className={`block ${bgColor} px-2 py-1 rounded text-center`}>
            {watch}
          </span>
        );
      },
    },
    {
      accessorKey: "incidentType",
      header: "Type",
      cell: ({ row }) => {
        const typeConfig = getIncidentTypeConfig(row.original.incidentType);
        return (
          <Badge className={`incident-type-badge ${typeConfig.badge}`}>
            {typeConfig.label}
          </Badge>
        );
      },
    },
    {
      accessorKey: "notes",
      header: "Notes",
      cell: ({ row }) => (
        <span className="block">
          {row.original.notes || ""}
        </span>
      ),
    },
    {
      id: "actions",
      header: "Edit",
      cell: ({ row }) => (
        <div className="text-center">
          <Button
            variant="ghost"
            size="icon"
            asChild
          >
            <Link to={`/incidents/${row.original.id}`}>
              <Edit className="h-4 w-4 text-primary" />
              <span className="sr-only">Edit</span>
            </Link>
          </Button>
        </div>
      ),
    },
  ];

  // Transform data for charts
  const incidentTypeData = Object.entries(stats?.byType || {})
    .map(([name, value]) => ({ name, value }))
    .sort((a, b) => b.value - a.value)
    .slice(0, 5);
  
  const incidentByTownData = Object.entries(stats?.byTown || {})
    .map(([name, value]) => ({ name, value }))
    .sort((a, b) => b.value - a.value)
    .slice(0, 5);

  const incidentByMonthData = Object.entries(stats?.byMonth || {})
    .map(([name, value]) => ({ name, value }))
    .sort((a, b) => {
      const months = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December", "Unknown"];
      return months.indexOf(a.name) - months.indexOf(b.name);
    });

  // Colors for charts
  const COLORS = ['#1a73e8', '#f44336', '#ff9800', '#4caf50', '#9c27b0'];

  return (
    <>
      <Helmet>
        <title>Dashboard | Emergency Response Incident Management System</title>
        <meta name="description" content="Overview of emergency response incidents and statistics for monitoring and analysis" />
      </Helmet>
      
      <div className="p-4 md:p-6">
        <div className="mb-6">
          <div className="flex flex-col md:flex-row md:items-center md:justify-between gap-4">
            <div>
              <h1 className="text-2xl font-bold text-neutral-800">Dashboard</h1>
              <p className="text-neutral-600">Overview of recent incidents and statistics</p>
            </div>
            <div className="flex flex-wrap gap-2">
              <Button className="inline-flex items-center" asChild>
                <Link href="/incidents/new">
                  <Plus className="mr-2 h-4 w-4" />
                  New Incident
                </Link>
              </Button>
              <Button
                variant="outline"
                className="inline-flex items-center text-primary"
                asChild
              >
                <Link href="/api/export/csv">
                  <FileDown className="mr-2 h-4 w-4" />
                  Export
                </Link>
              </Button>
            </div>
          </div>
        </div>

        {/* Stats Cards */}
        <div className="grid grid-cols-1 md:grid-cols-1 gap-4 mb-6">
          <Card className="col-span-full shadow-sm border border-neutral-200">
            <CardHeader>
              <CardTitle className="text-lg font-semibold">Total Incidents Per Watch</CardTitle>
            </CardHeader>
            <CardContent>
              <div className="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-5 gap-4">
                <div className="flex items-center space-x-4 p-4 rounded-lg bg-green-100">
                  <div className="bg-green-500 text-black font-medium p-2 rounded w-12 h-12 flex items-center justify-center">
                    <Flame className="h-8 w-8" />
                  </div>
                  <div>
                    <p className="text-sm font-medium text-gray-500">Green Watch</p>
                    <h3 className="text-2xl font-bold">{stats?.byWatch?.["Green Watch"] || 0}</h3>
                  </div>
                </div>
                
                <div className="flex items-center space-x-4 p-4 rounded-lg bg-red-100">
                  <div className="bg-red-500 text-black font-medium p-2 rounded w-12 h-12 flex items-center justify-center">
                    <Flame className="h-8 w-8" />
                  </div>
                  <div>
                    <p className="text-sm font-medium text-gray-500">Red Watch</p>
                    <h3 className="text-2xl font-bold">{stats?.byWatch?.["Red Watch"] || 0}</h3>
                  </div>
                </div>
                
                <div className="flex items-center space-x-4 p-4 rounded-lg bg-blue-100">
                  <div className="bg-blue-500 text-black font-medium p-2 rounded w-12 h-12 flex items-center justify-center">
                    <Flame className="h-8 w-8" />
                  </div>
                  <div>
                    <p className="text-sm font-medium text-gray-500">Blue Watch</p>
                    <h3 className="text-2xl font-bold">{stats?.byWatch?.["Blue Watch"] || 0}</h3>
                  </div>
                </div>
                
                <div className="flex items-center space-x-4 p-4 rounded-lg bg-gray-100">
                  <div className="bg-white border border-gray-300 text-black font-medium p-2 rounded w-12 h-12 flex items-center justify-center">
                    <Flame className="h-8 w-8" />
                  </div>
                  <div>
                    <p className="text-sm font-medium text-gray-500">White Watch</p>
                    <h3 className="text-2xl font-bold">{stats?.byWatch?.["White Watch"] || 0}</h3>
                  </div>
                </div>
                
                <div className="flex items-center space-x-4 p-4 rounded-lg bg-amber-100">
                  <div className="bg-amber-500 text-black font-medium p-2 rounded w-12 h-12 flex items-center justify-center">
                    <Flame className="h-8 w-8" />
                  </div>
                  <div>
                    <p className="text-sm font-medium text-gray-500">RDS</p>
                    <h3 className="text-2xl font-bold">{stats?.byWatch?.["RDS"] || 0}</h3>
                  </div>
                </div>
              </div>
            </CardContent>
          </Card>

          <div className="grid grid-cols-1 md:grid-cols-3 gap-4">
            <StatsCard
              title="Total Incidents"
              value={stats?.totalIncidents || 0}
              icon={Activity}
              iconColor="text-primary"
              iconBgColor="bg-blue-100"
              trend={{ value: "All Time", direction: "neutral" }}
            />
            
            <StatsCard
              title="Monthly Incidents"
              value={stats?.byPeriod?.monthly || 0}
              icon={Activity}
              iconColor="text-purple-500"
              iconBgColor="bg-purple-100"
              trend={{ value: "Current Month", direction: "neutral" }}
            />
            
            <StatsCard
              title="Weekly Incidents"
              value={stats?.byPeriod?.weekly || 0}
              icon={Activity}
              iconColor="text-green-500"
              iconBgColor="bg-green-100"
              trend={{ value: "Current Week", direction: "neutral" }}
            />
          </div>
        </div>

        {/* Charts Row */}
        <div className="grid grid-cols-1 lg:grid-cols-1 gap-6 mb-6">
          <Card className="shadow-sm border border-neutral-200">
            <CardHeader>
              <CardTitle className="text-lg font-semibold">Incidents by Type</CardTitle>
            </CardHeader>
            <CardContent>
              <div className="h-64">
                <ResponsiveContainer width="100%" height="100%">
                  <PieChart>
                    <Pie
                      data={incidentTypeData}
                      cx="50%"
                      cy="50%"
                      labelLine={false}
                      outerRadius={80}
                      fill="#8884d8"
                      dataKey="value"
                      label={({ name, percent }) => `${name}: ${(percent * 100).toFixed(0)}%`}
                    >
                      {incidentTypeData.map((entry, index) => (
                        <Cell key={`cell-${index}`} fill={COLORS[index % COLORS.length]} />
                      ))}
                    </Pie>
                    <Tooltip formatter={(value) => [`${value} incidents`, 'Count']} />
                  </PieChart>
                </ResponsiveContainer>
              </div>
            </CardContent>
          </Card>
        </div>

        {/* Recent Incidents Table */}
        <div className="mb-6">
          <h2 className="text-lg font-semibold text-neutral-800 mb-4">Recent Incidents</h2>
          <DataTable
            columns={recentIncidentsColumns}
            data={stats?.recentIncidents || []}
            isLoading={isLoading}
          />
        </div>
      </div>
    </>
  );
}
