import React, { useState, useEffect } from "react";
import { Helmet } from "react-helmet";
import {
  Card,
  CardContent,
  CardDescription,
  CardFooter,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import { Switch } from "@/components/ui/switch";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select";
import { 
  Save, 
  Trash2, 
  Download, 
  Upload, 
  User, 
  Bell, 
  Shield, 
  LifeBuoy,
  FileDown,
  Settings as SettingsIcon,
  Database
} from "lucide-react";
import { toast } from "@/hooks/use-toast";
import { Separator } from "@/components/ui/separator";
import { AlertDialog, AlertDialogAction, AlertDialogCancel, AlertDialogContent, AlertDialogDescription, AlertDialogFooter, AlertDialogHeader, AlertDialogTitle, AlertDialogTrigger } from "@/components/ui/alert-dialog";
import { useSettings } from "@/context/settings-context";

export default function Settings() {
  const [activeTab, setActiveTab] = useState("general");
  const [enableNotifications, setEnableNotifications] = useState(true);
  const [emailNotifications, setEmailNotifications] = useState(false);
  
  // Use the settings context
  const { 
    dateFormat, setDateFormat,
    timeFormat, setTimeFormat,
    darkMode, setDarkMode,
    autoSave, setAutoSave,
    incidentNumberPrefix, setIncidentNumberPrefix,
    saveSettings
  } = useSettings();

  const handleSaveSettings = () => {
    // Save settings to localStorage via the context
    saveSettings();
    
    toast({
      title: "Settings saved",
      description: "Your settings have been successfully saved.",
    });
  };

  const handleExportData = () => {
    window.location.href = "/api/export/csv";
  };

  const handleImportData = () => {
    toast({
      title: "Import feature",
      description: "The import feature is not available in this version.",
      variant: "destructive",
    });
  };

  const handleClearData = async () => {
    try {
      const response = await fetch('/api/incidents/clear', {
        method: 'POST',
      });
      
      if (response.ok) {
        toast({
          title: "Data cleared",
          description: "All incident data has been successfully removed.",
        });
        
        // Refresh the page to update the UI with the cleared data
        window.location.href = '/incidents';
      } else {
        const error = await response.json();
        throw new Error(error.message || 'Failed to clear data');
      }
    } catch (error) {
      toast({
        title: "Error",
        description: error instanceof Error ? error.message : "Failed to clear data",
        variant: "destructive",
      });
    }
  };

  const handleResetSettings = () => {
    // Reset settings to defaults
    setTimeFormat("24h");
    setDateFormat("yyyy-mm-dd");
    setEnableNotifications(true);
    setEmailNotifications(false);
    setDarkMode(false);
    setAutoSave(true);
    setIncidentNumberPrefix("HH");

    toast({
      title: "Settings reset",
      description: "Your settings have been reset to default values.",
    });
  };

  return (
    <>
      <Helmet>
        <title>Settings | Emergency Response Incident Management System</title>
        <meta name="description" content="Configure your emergency incident management system preferences" />
      </Helmet>
      
      <div className="p-4 md:p-6">
        <div className="mb-6">
          <div className="flex flex-col md:flex-row md:items-center md:justify-between gap-4">
            <div>
              <h1 className="text-2xl font-bold text-neutral-800">Settings</h1>
              <p className="text-neutral-600">Configure your incident management system</p>
            </div>
          </div>
        </div>

        <Tabs 
          defaultValue="general" 
          value={activeTab}
          onValueChange={setActiveTab}
          className="max-w-4xl mx-auto"
        >
          <TabsList className="grid grid-cols-2 md:grid-cols-4 mb-4">
            <TabsTrigger value="general" className="flex items-center gap-2">
              <SettingsIcon className="h-4 w-4" />
              <span>General</span>
            </TabsTrigger>
            <TabsTrigger value="data" className="flex items-center gap-2">
              <Database className="h-4 w-4" />
              <span>Data Management</span>
            </TabsTrigger>
            <TabsTrigger value="account" className="flex items-center gap-2">
              <User className="h-4 w-4" />
              <span>Account</span>
            </TabsTrigger>
            <TabsTrigger value="notifications" className="flex items-center gap-2">
              <Bell className="h-4 w-4" />
              <span>Notifications</span>
            </TabsTrigger>
          </TabsList>
          
          {/* General Settings Tab */}
          <TabsContent value="general">
            <Card>
              <CardHeader>
                <CardTitle>General Settings</CardTitle>
                <CardDescription>
                  Configure basic application settings
                </CardDescription>
              </CardHeader>
              <CardContent className="space-y-6">
                <div className="space-y-4">
                  <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                    <div className="space-y-2">
                      <Label htmlFor="time-format">Time Format</Label>
                      <Select value={timeFormat} onValueChange={setTimeFormat}>
                        <SelectTrigger id="time-format">
                          <SelectValue placeholder="Select time format" />
                        </SelectTrigger>
                        <SelectContent>
                          <SelectItem value="12h">12 Hour (AM/PM)</SelectItem>
                          <SelectItem value="24h">24 Hour</SelectItem>
                        </SelectContent>
                      </Select>
                    </div>
                    
                    <div className="space-y-2">
                      <Label htmlFor="date-format">Date Format</Label>
                      <Select value={dateFormat} onValueChange={setDateFormat}>
                        <SelectTrigger id="date-format">
                          <SelectValue placeholder="Select date format" />
                        </SelectTrigger>
                        <SelectContent>
                          <SelectItem value="yyyy-mm-dd">YYYY-MM-DD</SelectItem>
                          <SelectItem value="dd-mm-yyyy">DD-MM-YYYY</SelectItem>
                          <SelectItem value="mm-dd-yyyy">MM-DD-YYYY</SelectItem>
                        </SelectContent>
                      </Select>
                    </div>
                  </div>
                  
                  <div className="space-y-2">
                    <Label htmlFor="incident-prefix">Incident Number Prefix</Label>
                    <Input 
                      id="incident-prefix"
                      value={incidentNumberPrefix}
                      onChange={(e) => setIncidentNumberPrefix(e.target.value)}
                      placeholder="e.g. HH"
                      maxLength={4}
                    />
                    <p className="text-sm text-muted-foreground">
                      Example: {incidentNumberPrefix}032473
                    </p>
                  </div>

                  <div className="flex items-center justify-between">
                    <div className="space-y-0.5">
                      <Label htmlFor="dark-mode">Dark Mode</Label>
                      <p className="text-sm text-muted-foreground">
                        Enable dark mode for the interface
                      </p>
                    </div>
                    <Switch
                      id="dark-mode"
                      checked={darkMode}
                      onCheckedChange={setDarkMode}
                    />
                  </div>

                  <div className="flex items-center justify-between">
                    <div className="space-y-0.5">
                      <Label htmlFor="auto-save">Auto Save Drafts</Label>
                      <p className="text-sm text-muted-foreground">
                        Automatically save form drafts while editing
                      </p>
                    </div>
                    <Switch
                      id="auto-save"
                      checked={autoSave}
                      onCheckedChange={setAutoSave}
                    />
                  </div>
                </div>
              </CardContent>
              <CardFooter className="flex justify-between">
                <Button 
                  variant="outline" 
                  onClick={handleResetSettings}
                >
                  Reset to Default
                </Button>
                <Button 
                  onClick={handleSaveSettings}
                >
                  <Save className="mr-2 h-4 w-4" />
                  Save Changes
                </Button>
              </CardFooter>
            </Card>
          </TabsContent>
          
          {/* Data Management Tab */}
          <TabsContent value="data">
            <Card>
              <CardHeader>
                <CardTitle>Data Management</CardTitle>
                <CardDescription>
                  Import, export, or clear your incident data
                </CardDescription>
              </CardHeader>
              <CardContent className="space-y-4">
                <div className="space-y-4">
                  <div className="p-4 border rounded-md bg-neutral-50">
                    <h3 className="font-medium mb-2">Export Options</h3>
                    <p className="text-sm text-muted-foreground mb-4">
                      Export your incident data in various formats
                    </p>
                    <div className="flex flex-wrap gap-2">
                      <Button 
                        variant="outline" 
                        onClick={handleExportData}
                        className="gap-2"
                      >
                        <FileDown className="h-4 w-4" />
                        Export as CSV
                      </Button>
                      <Button 
                        variant="outline" 
                        className="gap-2"
                      >
                        <Download className="h-4 w-4" />
                        Export as PDF
                      </Button>
                    </div>
                  </div>
                  
                  <div className="p-4 border rounded-md bg-neutral-50">
                    <h3 className="font-medium mb-2">Import Data</h3>
                    <p className="text-sm text-muted-foreground mb-4">
                      Import incident records from a CSV file
                    </p>
                    <Button 
                      variant="outline" 
                      onClick={handleImportData}
                      className="gap-2"
                    >
                      <Upload className="h-4 w-4" />
                      Import CSV
                    </Button>
                  </div>
                  
                  <div className="p-4 border rounded-md border-destructive/20 bg-destructive/5">
                    <h3 className="font-medium text-destructive mb-2">Danger Zone</h3>
                    <p className="text-sm text-muted-foreground mb-4">
                      These actions cannot be undone
                    </p>
                    <AlertDialog>
                      <AlertDialogTrigger asChild>
                        <Button 
                          variant="destructive" 
                          className="gap-2"
                        >
                          <Trash2 className="h-4 w-4" />
                          Clear All Data
                        </Button>
                      </AlertDialogTrigger>
                      <AlertDialogContent>
                        <AlertDialogHeader>
                          <AlertDialogTitle>Are you absolutely sure?</AlertDialogTitle>
                          <AlertDialogDescription>
                            This action cannot be undone. This will permanently delete all
                            incident records and cannot be recovered.
                          </AlertDialogDescription>
                        </AlertDialogHeader>
                        <AlertDialogFooter>
                          <AlertDialogCancel>Cancel</AlertDialogCancel>
                          <AlertDialogAction
                            onClick={handleClearData}
                            className="bg-destructive text-destructive-foreground"
                          >
                            Yes, clear all data
                          </AlertDialogAction>
                        </AlertDialogFooter>
                      </AlertDialogContent>
                    </AlertDialog>
                  </div>
                </div>
              </CardContent>
            </Card>
          </TabsContent>
          
          {/* Account Tab */}
          <TabsContent value="account">
            <Card>
              <CardHeader>
                <CardTitle>Account Settings</CardTitle>
                <CardDescription>
                  Manage your account details and preferences
                </CardDescription>
              </CardHeader>
              <CardContent className="space-y-6">
                <div className="space-y-4">
                  <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                    <div className="space-y-2">
                      <Label htmlFor="full-name">Full Name</Label>
                      <Input 
                        id="full-name"
                        placeholder="John Doe"
                        defaultValue="John Doe"
                      />
                    </div>
                    
                    <div className="space-y-2">
                      <Label htmlFor="email">Email Address</Label>
                      <Input 
                        id="email"
                        type="email"
                        placeholder="john.doe@example.com"
                        defaultValue="john.doe@example.com"
                      />
                    </div>
                  </div>
                  
                  <div className="space-y-2">
                    <Label htmlFor="job-title">Job Title</Label>
                    <Input 
                      id="job-title"
                      placeholder="Station Officer"
                      defaultValue="Station Officer"
                    />
                  </div>
                  
                  <Separator />
                  
                  <div className="space-y-2">
                    <Label htmlFor="current-password">Current Password</Label>
                    <Input 
                      id="current-password"
                      type="password"
                      placeholder="Enter your current password"
                    />
                  </div>
                  
                  <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                    <div className="space-y-2">
                      <Label htmlFor="new-password">New Password</Label>
                      <Input 
                        id="new-password"
                        type="password"
                        placeholder="Enter new password"
                      />
                    </div>
                    
                    <div className="space-y-2">
                      <Label htmlFor="confirm-password">Confirm New Password</Label>
                      <Input 
                        id="confirm-password"
                        type="password"
                        placeholder="Confirm new password"
                      />
                    </div>
                  </div>
                </div>
              </CardContent>
              <CardFooter className="flex justify-end">
                <Button onClick={handleSaveSettings}>
                  <Save className="mr-2 h-4 w-4" />
                  Save Changes
                </Button>
              </CardFooter>
            </Card>
          </TabsContent>
          
          {/* Notifications Tab */}
          <TabsContent value="notifications">
            <Card>
              <CardHeader>
                <CardTitle>Notification Settings</CardTitle>
                <CardDescription>
                  Configure how and when you receive notifications
                </CardDescription>
              </CardHeader>
              <CardContent className="space-y-6">
                <div className="space-y-4">
                  <div className="flex items-center justify-between">
                    <div className="space-y-0.5">
                      <Label htmlFor="enable-notifications">Enable Notifications</Label>
                      <p className="text-sm text-muted-foreground">
                        Receive notifications about new incidents and updates
                      </p>
                    </div>
                    <Switch
                      id="enable-notifications"
                      checked={enableNotifications}
                      onCheckedChange={setEnableNotifications}
                    />
                  </div>
                  
                  <div className="flex items-center justify-between">
                    <div className="space-y-0.5">
                      <Label htmlFor="email-notifications">Email Notifications</Label>
                      <p className="text-sm text-muted-foreground">
                        Receive email notifications for critical updates
                      </p>
                    </div>
                    <Switch
                      id="email-notifications"
                      checked={emailNotifications}
                      onCheckedChange={setEmailNotifications}
                      disabled={!enableNotifications}
                    />
                  </div>
                  
                  <Separator />
                  
                  <div className="space-y-2">
                    <h3 className="text-sm font-medium">Notification Types</h3>
                    <div className="space-y-2">
                      <div className="flex items-center space-x-2">
                        <Checkbox id="notify-new-incident" defaultChecked disabled={!enableNotifications} />
                        <label
                          htmlFor="notify-new-incident"
                          className={`text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70 ${!enableNotifications ? 'text-muted-foreground' : ''}`}
                        >
                          New incident created
                        </label>
                      </div>
                      <div className="flex items-center space-x-2">
                        <Checkbox id="notify-update" defaultChecked disabled={!enableNotifications} />
                        <label
                          htmlFor="notify-update"
                          className={`text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70 ${!enableNotifications ? 'text-muted-foreground' : ''}`}
                        >
                          Incident updates
                        </label>
                      </div>
                      <div className="flex items-center space-x-2">
                        <Checkbox id="notify-safety-check" defaultChecked disabled={!enableNotifications} />
                        <label
                          htmlFor="notify-safety-check"
                          className={`text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70 ${!enableNotifications ? 'text-muted-foreground' : ''}`}
                        >
                          Safety check required
                        </label>
                      </div>
                      <div className="flex items-center space-x-2">
                        <Checkbox id="notify-system" defaultChecked={false} disabled={!enableNotifications} />
                        <label
                          htmlFor="notify-system"
                          className={`text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70 ${!enableNotifications ? 'text-muted-foreground' : ''}`}
                        >
                          System notifications
                        </label>
                      </div>
                    </div>
                  </div>
                </div>
              </CardContent>
              <CardFooter className="flex justify-end">
                <Button onClick={handleSaveSettings}>
                  <Save className="mr-2 h-4 w-4" />
                  Save Changes
                </Button>
              </CardFooter>
            </Card>
          </TabsContent>
        </Tabs>
      </div>
    </>
  );
}

// Checkbox component since it's used only in this file
function Checkbox({ id, defaultChecked, disabled }: { id: string, defaultChecked?: boolean, disabled?: boolean }) {
  return (
    <div className="flex items-center">
      <input
        type="checkbox"
        id={id}
        defaultChecked={defaultChecked}
        disabled={disabled}
        className="h-4 w-4 text-primary focus:ring-primary border-neutral-300 rounded cursor-pointer disabled:cursor-not-allowed disabled:opacity-70"
      />
    </div>
  );
}
